summaryrefslogtreecommitdiffstats
path: root/karm/karmstorage.h
diff options
context:
space:
mode:
Diffstat (limited to 'karm/karmstorage.h')
-rw-r--r--karm/karmstorage.h86
1 files changed, 43 insertions, 43 deletions
diff --git a/karm/karmstorage.h b/karm/karmstorage.h
index c8465829..6c02ca90 100644
--- a/karm/karmstorage.h
+++ b/karm/karmstorage.h
@@ -23,8 +23,8 @@
#ifndef KARM_STORAGE_H
#define KARM_STORAGE_H
-#include <qdict.h>
-#include <qptrstack.h>
+#include <tqdict.h>
+#include <tqptrstack.h>
#include "journal.h"
#include "reportcriteria.h"
@@ -100,19 +100,19 @@ class KarmStorage
* @return empty string if success, error message if error.
*
*/
- QString load(TaskView* taskview, const Preferences* preferences, QString fileName="" );
+ TQString load(TaskView* taskview, const Preferences* preferences, TQString fileName="" );
/*
* Return the name of the iCal file
*/
- QString icalfile();
+ TQString icalfile();
/*
* Build up the taskview.
*
* This is needed if the iCal file has been modified
*/
- QString buildTaskView(KCal::ResourceCalendar *rc, TaskView *view);
+ TQString buildTaskView(KCal::ResourceCalendar *rc, TaskView *view);
/* Close calendar and clear view. Release lock if holding one. */
void closeStorage(TaskView* view);
@@ -127,7 +127,7 @@ class KarmStorage
*
* @param taskview The list group used in the TaskView
*/
- QString save(TaskView* taskview);
+ TQString save(TaskView* taskview);
/**
* Read tasks and their total times from a text file (legacy storage).
@@ -142,7 +142,7 @@ class KarmStorage
* string task name
* [string] desktops, in which to count. e.g. "1,2,5" (optional)
*/
- QString loadFromFlatFile(TaskView* taskview, const QString& filename);
+ TQString loadFromFlatFile(TaskView* taskview, const TQString& filename);
/**
* Reads tasks and their total times from text file (legacy).
@@ -152,13 +152,13 @@ class KarmStorage
*
* @see loadFromFlatFile
*/
- QString loadFromFlatFileCumulative(TaskView* taskview,
- const QString& filename);
+ TQString loadFromFlatFileCumulative(TaskView* taskview,
+ const TQString& filename);
/**
Output a report based on contents of ReportCriteria.
*/
- QString report( TaskView *taskview, const ReportCriteria &rc );
+ TQString report( TaskView *taskview, const ReportCriteria &rc );
/**
* Log the change in a task's time.
@@ -203,7 +203,7 @@ class KarmStorage
* @return true if event was added, false if not (if, for example, the
* attempted file lock failed).
*/
- bool bookTime(const Task* task, const QDateTime& startDateTime,
+ bool bookTime(const Task* task, const TQDateTime& startDateTime,
long durationInSeconds);
/**
@@ -217,7 +217,7 @@ class KarmStorage
* @param oldname The old name of the task. The new name is in the task
* object already.
*/
- void setName(const Task* task, const QString& oldname) { Q_UNUSED(task); Q_UNUSED(oldname); }
+ void setName(const Task* task, const TQString& oldname) { Q_UNUSED(task); Q_UNUSED(oldname); }
/**
@@ -239,7 +239,7 @@ class KarmStorage
*
* @param task The task the timer was stopped for.
*/
- void stopTimer(const Task* task, QDateTime when=QDateTime::currentDateTime());
+ void stopTimer(const Task* task, TQDateTime when=TQDateTime::currentDateTime());
/**
* Log a new comment for this task.
@@ -250,7 +250,7 @@ class KarmStorage
* @param task The task that gets the comment
* @param comment The comment
*/
- void addComment(const Task* task, const QString& comment);
+ void addComment(const Task* task, const TQString& comment);
/**
@@ -272,10 +272,10 @@ class KarmStorage
* @param task The task to be removed.
* @param parent The parent of this task. Must have a uid() that is in
* the existing calendar. If zero, this task is considered a root task.
* @return The unique ID for the new VTODO. Return an null QString if
* there was an error creating the new calendar object.
*/
- QString addTask(const Task* task, const Task* parent);
+ TQString addTask(const Task* task, const Task* parent);
/**
* Check if the iCalendar file currently loaded has any Todos in it.
@@ -297,23 +297,23 @@ class KarmStorage
bool isNewStorage(const Preferences* preferences) const;
/** Return a list of start/stop events for the given date range. */
- QValueList<HistoryEvent> getHistory(const QDate& from, const QDate& to);
+ TQValueList<HistoryEvent> getHistory(const TQDate& from, const TQDate& to);
private:
static KarmStorage *_instance;
KCal::ResourceCalendar *_calendar;
- QString _icalfile;
+ TQString _icalfile;
KarmStorage();
void adjustFromLegacyFileFormat(Task* task);
- bool parseLine(QString line, long *time, QString *name, int *level,
+ bool parseLine(TQString line, long *time, TQString *name, int *level,
DesktopList* desktopList);
- QString writeTaskAsTodo
- (Task* task, const int level, QPtrStack< KCal::Todo >& parents);
+ TQString writeTaskAsTodo
+ (Task* task, const int level, TQPtrStack< KCal::Todo >& parents);
bool saveCalendar();
KCal::Event* baseEvent(const Task*);
- bool remoteResource( const QString& file ) const;
+ bool remoteResource( const TQString& file ) const;
/**
* Writes all tasks and their totals to a Comma-Separated Values file.
@@ -322,26 +322,26 @@ class KarmStorage
* taskName,subtaskName,..,sessionTime,time,totalSessionTime,totalTime
* the number of subtasks is determined at runtime.
*/
- QString exportcsvFile( TaskView *taskview, const ReportCriteria &rc );
+ TQString exportcsvFile( TaskView *taskview, const ReportCriteria &rc );
/**
* Write task history to file as comma-delimited data.
*/
- QString exportcsvHistory (
+ TQString exportcsvHistory (
TaskView* taskview,
- const QDate& from,
- const QDate& to,
+ const TQDate& from,
+ const TQDate& to,
const ReportCriteria &rc
);
long printTaskHistory (
const Task *task,
- const QMap<QString,long>& taskdaytotals,
- QMap<QString,long>& daytotals,
- const QDate& from,
- const QDate& to,
+ const TQMap<TQString,long>& taskdaytotals,
+ TQMap<TQString,long>& daytotals,
+ const TQDate& from,
+ const TQDate& to,
const int level,
- std::vector <QString> &matrix,
+ std::vector <TQString> &matrix,
const ReportCriteria &rc
);
};
@@ -358,23 +358,23 @@ class HistoryEvent
public:
/** Needed to be used in a value list. */
HistoryEvent() {}
- HistoryEvent(QString uid, QString name, long duration,
- QDateTime start, QDateTime stop, QString todoUid);
- QString uid() {return _uid; }
- QString name() {return _name; }
+ HistoryEvent(TQString uid, TQString name, long duration,
+ TQDateTime start, TQDateTime stop, TQString todoUid);
+ TQString uid() {return _uid; }
+ TQString name() {return _name; }
/** In seconds. */
long duration() {return _duration; }
- QDateTime start() {return _start; }
- QDateTime stop() { return _stop; }
- QString todoUid() {return _todoUid; }
+ TQDateTime start() {return _start; }
+ TQDateTime stop() { return _stop; }
+ TQString todoUid() {return _todoUid; }
private:
- QString _uid;
- QString _todoUid;
- QString _name;
+ TQString _uid;
+ TQString _todoUid;
+ TQString _name;
long _duration;
- QDateTime _start;
- QDateTime _stop;
+ TQDateTime _start;
+ TQDateTime _stop;
};
@@ -272,10 +272,10 @@ class KarmStorage
* @param parent The parent of this task. Must have a uid() that is in
* the existing calendar. If zero, this task is considered a root task.
- * @return The unique ID for the new VTODO. Return an null QString if
+ * @return The unique ID for the new VTODO. Return an null TQString if
* there was an error creating the new calendar object.
*/